@@ -44,7 +44,7 @@ def optimize_grid(labels_train_true, probs_train_pred, gap_durs, min_lens, segme
 def optimize(dataset_path: str,
              model_save_name: str,
              gap_durs: Optional[List[float]] = None,
-             min_lens: Optional[List[float]] = None) -> Tuple[float, float, float, Dict[str, Union[float, List[float]]]]:
+             min_lens: Optional[List[float]] = None) -> Tuple[float, float, Dict[str, Union[float, List[float]]]]:
     """[summary]
 
     Args:
@@ -54,10 +54,10 @@ def optimize(dataset_path: str,
         min_lens (Optional[List[float]], optional): in seconds. Defaults to None.
 
     Returns:
-        Tuple[float, float, float, Dict[str, Union[float, List[float]]]]: [description]
+        Tuple[float, float, Dict[str, Union[float, List[float]]]]: [description]
     """
 
-    data = das.io.npy_dir.load(dataset_path)
+    data = das.io.npy_dir.load(dataset_path, memmap_dirs='all')
     fs = data.attrs['samplerate_x_Hz']
 
     # sensible(?) defaults 0.5--1000ms
@@ -75,7 +75,6 @@ def optimize(dataset_path: str,
         min_lens = (values * fs).astype(np.int)
 
     # get raw predictions to run post-processing on
-    # TODO better to load_model_and_params once and pass to predict here and below
     _, segments, probs_train_pred, _ = das.predict.predict(data['train']['x'], model_save_name=model_save_name)
     labels_train_true = postprocess(data['train']['y'], segment_dims=segments['index'], segment_names=segments['names'])
 
@@ -119,13 +118,13 @@ def optimize(dataset_path: str,
         score_val = None
 
     # from samples to seconds
-    best_gap_dur, best_min_len = best_gap_dur / fs, best_min_len / fs
+    best_gap_dur, best_min_len = float(best_gap_dur / fs), float(best_min_len / fs)
 
     scores = {
-        'train_pre': score_train_pre,
-        'train': score_train,
-        'val_pre': score_val_pre,
-        'val': score_val,
+        'train_pre': float(score_train_pre),
+        'train': float(score_train),
+        'val_pre': float(score_val_pre),
+        'val': float(score_val),
         'all_train': f1_scores
     }
 
