@@ -1,6 +1,12 @@
+import logging
 import tensorflow.keras as keras
-# import tensorflow_probability as tfp
 import tensorflow as tf
+try:
+    import tensorflow_probability as tfp
+except ImportError:
+    tfp = None
+    logging.warning('No tensorflow-probability.')
+    pass
 
 
 class MelSpec(keras.layers.Layer):
@@ -10,8 +16,8 @@ class MelSpec(keras.layers.Layer):
         self,
         sampling_rate,
         frame_length=512,
-        frame_step=128,
-        fft_length=4096,
+        frame_step=None,
+        fft_length=None,
         num_mel_channels=128,
         freq_min=0,
         freq_max=None,
@@ -20,12 +26,20 @@ class MelSpec(keras.layers.Layer):
         super().__init__(**kwargs)
         self.sampling_rate = sampling_rate
         self.frame_length = frame_length
+
+        if frame_step is None:
+            frame_step = self.frame_length // 4
         self.frame_step = frame_step
+
+        if fft_length is None:
+            fft_length = self.frame_length * 2
         self.fft_length = fft_length
+
         self.num_mel_channels = num_mel_channels
         self.freq_min = freq_min
+
         if freq_max is None:
-            freq_max = int(self.sampling_rate / 2)
+            freq_max = self.sampling_rate // 2
         self.freq_max = freq_max
 
         # Defining mel filter. This filter will be multiplied with the STFT output
@@ -57,10 +71,11 @@ class MelSpec(keras.layers.Layer):
         mel = tf.matmul(tf.square(magnitude), self.mel_filterbank)
 
         # # baseline subtract
-        # baseline = tfp.stats.percentile(mel, 50, axis=1, keepdims=True)
-        # mel = tf.math.log(mel/baseline)
-        # mel = tf.clip_by_value(mel, clip_value_min=0, clip_value_max=100_000)
-        # mel /= tf.reduce_max(mel) * 255
+        if tfp is not None:
+            baseline = tfp.stats.percentile(mel, 50, axis=1, keepdims=True)
+            mel = tf.math.log(mel/(baseline + 0.000001))
+            mel = tf.clip_by_value(mel, clip_value_min=0, clip_value_max=100_000)
+            mel /= tf.reduce_max(mel) * 255
         return mel
 
     def get_config(self):
@@ -77,20 +92,3 @@ class MelSpec(keras.layers.Layer):
             }
         )
         return config
-
-
-def dbscale(input, top_db, name=None):
-    """
-    Turn spectrogram into db scale
-    Args:
-      input: A spectrogram Tensor.
-      top_db: Minimum negative cut-off `max(10 * log10(S)) - top_db`
-      name: A name for the operation (optional).
-    Returns:
-      A tensor of mel spectrogram with shape [frames, mels].
-    """
-    # copied from tfio.audio.dbscale
-    power = tf.math.square(input)
-    log_spec = 10.0 * (tf.math.log(power) / tf.math.log(10.0))
-    log_spec = tf.math.maximum(log_spec, tf.math.reduce_max(log_spec) - top_db)
-    return log_spec
\ No newline at end of file
